==> zio-aws-ec2_2.12-5.17.130.5-sources.jar: zio/aws/ec2/model/NetworkInterfaceCount.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class NetworkInterfaceCount(
    min: Option[Integer] = None,
    max: Option[Integer] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.NetworkInterfaceCount = {
    import NetworkInterfaceCount.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.NetworkInterfaceCount
      .builder()
      .optionallyWith(min.map(value => value: java.lang.Integer))(_.min)
      .optionallyWith(max.map(value => value: java.lang.Integer))(_.max)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.NetworkInterfaceCount.ReadOnly =
    zio.aws.ec2.model.NetworkInterfaceCount.wrap(buildAwsValue())
}
object NetworkInterfaceCount {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.NetworkInterfaceCount
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.NetworkInterfaceCount = zio.aws.ec2.model
      .NetworkInterfaceCount(min.map(value => value), max.map(value => value))
    def min: Option[Integer]
    def max: Option[Integer]
    def getMin: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("min", min)
    def getMax: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("max", max)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.NetworkInterfaceCount
  ) extends zio.aws.ec2.model.NetworkInterfaceCount.ReadOnly {
    override val min: Option[Integer] =
      scala.Option(impl.min()).map(value => value: Integer)
    override val max: Option[Integer] =
      scala.Option(impl.max()).map(value => value: Integer)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.NetworkInterfaceCount
  ): zio.aws.ec2.model.NetworkInterfaceCount.ReadOnly = new Wrapper(impl)
}

==> zio-aws-ec2_2.12-5.20.7.3-sources.jar: zio/aws/ec2/model/NetworkInterfaceCount.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class NetworkInterfaceCount(
    min: Optional[Integer] = Optional.Absent,
    max: Optional[Integer] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.NetworkInterfaceCount = {
    import NetworkInterfaceCount.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.NetworkInterfaceCount
      .builder()
      .optionallyWith(min.map(value => value: java.lang.Integer))(_.min)
      .optionallyWith(max.map(value => value: java.lang.Integer))(_.max)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.NetworkInterfaceCount.ReadOnly =
    zio.aws.ec2.model.NetworkInterfaceCount.wrap(buildAwsValue())
}
object NetworkInterfaceCount {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.NetworkInterfaceCount
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.NetworkInterfaceCount = zio.aws.ec2.model
      .NetworkInterfaceCount(min.map(value => value), max.map(value => value))
    def min: Optional[Integer]
    def max: Optional[Integer]
    def getMin: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("min", min)
    def getMax: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("max", max)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.NetworkInterfaceCount
  ) extends zio.aws.ec2.model.NetworkInterfaceCount.ReadOnly {
    override val min: Optional[Integer] = zio.aws.core.internal
      .optionalFromNullable(impl.min())
      .map(value => value: Integer)
    override val max: Optional[Integer] = zio.aws.core.internal
      .optionalFromNullable(impl.max())
      .map(value => value: Integer)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.NetworkInterfaceCount
  ): zio.aws.ec2.model.NetworkInterfaceCount.ReadOnly = new Wrapper(impl)
}
